pub struct Parameter { /* private fields */ }Expand description
Dna parameter. These are recorded for interactive and optimization purposes.
Implementations
Sourceimpl Parameter
impl Parameter
Sourcepub fn new(
kind: ParameterKind,
name: String,
value: String,
value_f32: Option<f32>,
address: Vec<u32>,
maximum: u32,
raw: u32,
hash: u64,
choices: Vec<String>,
) -> Self
pub fn new( kind: ParameterKind, name: String, value: String, value_f32: Option<f32>, address: Vec<u32>, maximum: u32, raw: u32, hash: u64, choices: Vec<String>, ) -> Self
Create a new Parameter.
Sourcepub fn kind(&self) -> ParameterKind
pub fn kind(&self) -> ParameterKind
Parameter kind.
Sourcepub fn address(&self) -> &Vec<u32>
pub fn address(&self) -> &Vec<u32>
Address in the parameter tree where this parameter was drawn.
Sourcepub fn maximum_f32(&self) -> f32
pub fn maximum_f32(&self) -> f32
Raw maximum value of the parameter as an f32.