pub trait Hasher: Clone + Sync + Send {
    fn query(&self, seed: u64, frequency: f32, point: Vec3a) -> Basis;
    fn hash_x(&self, basis: &Basis, previous: u64, dx: i32) -> u64;
    fn hash_y(&self, basis: &Basis, previous: u64, dy: i32) -> u64;
    fn hash_z(&self, basis: &Basis, previous: u64, dz: i32) -> u64;
    fn get_code(&self) -> String;
}
Hashers supply data for grid cells and determine the topology of the procedural texture.

Required Methods

Builds a grid around a point. The seed is texture specific.

Hashes X coordinate. Supply any previous coordinate hashes in the previous argument.

Hashes Y coordinate. Supply any previous coordinate hashes in the previous argument.

Hashes Z coordinate. Supply any previous coordinate hashes in the previous argument.

Returns a code string that constructs this hasher.

Implementors