Texture unary and binary operators.
Structs
Displaces lookup of one texture by values from another texture.
Layers one texture on another with weight depending on distance between texture values.
Saturates components while retaining component proportions.
Posterize: applies a smooth step function in proportion to texture value magnitude.
Reflect: applies a wavy function to texture values with an offset, which can
spread and reflect components.
Rotates values of one texture with values from another texture.
Saturates components.
Mixes between two textures weighted with their vector magnitudes.
Applies a wavy function in proportion to vector magnitude.
Zero texture.
Functions
Saturates components (amount > 0).
Amount equals derivative at origin. Amounts greater than 1 result in overdrive.
Posterize: applies a smooth step function in proportion to texture value magnitude.
Applies a wavy function to texture values with an offset, which can
spread and reflect components. Amount is the scale (amount > 0),
roughly corresponding to number of reflections.
Amount is the maximum rotation in radians.
Saturates components (amount > 0).
Amount equals derivative at origin. Amounts greater than 1 result in overdrive.
Applies a wavy function in proportion to vector magnitude.
Zero texture.